<?xml version="1.0" encoding="UTF-8"?>
<!--
 - Desc:    This file is part of the eCromedos document preparation system
 - Date:    2006/03/09
 - Author:  Tobias Koch (tkoch@ecromedos.net)
 - License: GNU General Public License, version 2
 - URL:     http://www.ecromedos.net
-->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

<!--
  - Process simple bullet lists.
-->
<xsl:template match="ul">
	<ul>
		<xsl:apply-templates/>
	</ul>
</xsl:template>

<!--
  - Handle enumerated lists.
-->
<xsl:template match="ol">
	<xsl:variable name="num_ancestors">
		<xsl:value-of select="count(ancestor::ol)"/>
	</xsl:variable>
	<xsl:variable name="style">
		<xsl:choose>
			<xsl:when test="$num_ancestors = 3">
				<xsl:text>A</xsl:text>
			</xsl:when>
			<xsl:when test="$num_ancestors = 2">
				<xsl:text>i</xsl:text>
			</xsl:when>
			<xsl:when test="$num_ancestors = 1">
				<xsl:text>a</xsl:text>
			</xsl:when>
		</xsl:choose>
	</xsl:variable>
	<ol>
		<xsl:if test="$num_ancestors > 0">
			<xsl:attribute name="type">
				<xsl:value-of select="$style"/>
			</xsl:attribute>
		</xsl:if>
		<xsl:apply-templates/>
	</ol>
</xsl:template>

<!--
  - Set a list item in bullet/enumerated lists.
-->
<xsl:template match="li">
	<li>
		<xsl:apply-templates/>
	</li>
</xsl:template>

<!--
  - Process a glossary-type list.
-->
<xsl:template match="dl">
	<dl>
		<xsl:apply-templates select="dt|dd"/>
	</dl>
</xsl:template>

<!--
  - Set an item in glossary lists...
-->
<xsl:template match="dt">
	<dt>
		<xsl:apply-templates/>
	</dt>
</xsl:template>

<!--
  - ...and its definition
-->
<xsl:template match="dd">
	<dd>
		<xsl:apply-templates/>
	</dd>
</xsl:template>

</xsl:stylesheet>
